==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTRANKINGID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EQUIPMENTRANKINGID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EQUIPMENTRANKINGID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EQUIPMENTRANKINGID_Type", propOrder = {
    "equipmentid",
    "reliabilityrankingid"
})
public class EQUIPMENTRANKINGID_Type {

    @XmlElement(name = "EQUIPMENTID", required = true)
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "RELIABILITYRANKINGID", required = true)
    protected RELIABILITYRANKINGID_Type reliabilityrankingid;

    /**
     * Obtient la valeur de la propriété equipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Définit la valeur de la propriété equipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété reliabilityrankingid.
     * 
     * @return
     *     possible object is
     *     {@link RELIABILITYRANKINGID_Type }
     *     
     */
    public RELIABILITYRANKINGID_Type getRELIABILITYRANKINGID() {
        return reliabilityrankingid;
    }

    /**
     * Définit la valeur de la propriété reliabilityrankingid.
     * 
     * @param value
     *     allowed object is
     *     {@link RELIABILITYRANKINGID_Type }
     *     
     */
    public void setRELIABILITYRANKINGID(RELIABILITYRANKINGID_Type value) {
        this.reliabilityrankingid = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTRANKINGID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EQUIPMENTRANKINGID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EQUIPMENTRANKINGID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EQUIPMENTRANKINGID_Type", propOrder = {
    "equipmentid",
    "reliabilityrankingid"
})
public class EQUIPMENTRANKINGID_Type {

    @XmlElement(name = "EQUIPMENTID", required = true)
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "RELIABILITYRANKINGID", required = true)
    protected RELIABILITYRANKINGID_Type reliabilityrankingid;

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Gets the value of the reliabilityrankingid property.
     * 
     * @return
     *     possible object is
     *     {@link RELIABILITYRANKINGID_Type }
     *     
     */
    public RELIABILITYRANKINGID_Type getRELIABILITYRANKINGID() {
        return reliabilityrankingid;
    }

    /**
     * Sets the value of the reliabilityrankingid property.
     * 
     * @param value
     *     allowed object is
     *     {@link RELIABILITYRANKINGID_Type }
     *     
     */
    public void setRELIABILITYRANKINGID(RELIABILITYRANKINGID_Type value) {
        this.reliabilityrankingid = value;
    }

}
